@@ -13,11 +13,18 @@ int   n_completion_items = 15;
 static const char FORMAT_COMMAND[]     = "<b>%s</b>";
 static const char FORMAT_DESCRIPTION[] = "<i>%s</i>";
 
+/* Use XDG directory specification if no config and data directory are given on
+ * the command line. Uncomment the next line if you just want to use CONFIG_DIR
+ * and DATA_DIR instead (these will be the default locations if the XDG_*
+ * environment variebles are not set anyway) */
+/* #define ZATHURA_NO_XDG */
+
 /* directories and files */
 static const char BOOKMARK_FILE[] = "bookmarks";
 static const char ZATHURA_RC[]    = "zathurarc";
 static const char GLOBAL_RC[]     = "/etc/zathurarc";
-char*             zathura_dir     = "~/.config/zathura";
+static const char CONFIG_DIR[]    = "~/.config/zathura";
+static const char DATA_DIR[]      = "~/.local/share/zathura";
 
 /* bookmarks */
 static const char BM_PAGE_ENTRY[]  = "page";
@@ -59,6 +66,7 @@ char* uri_command = "firefox %s"; /* uri */
 
 /* additional settings */
 gboolean show_scrollbars = FALSE;
+gboolean scroll_wrap     = TRUE;
 int adjust_open          = ADJUST_BESTFIT;
 #define SELECTION_STYLE POPPLER_SELECTION_GLYPH
 #define GOTO_MODE GOTO_LABELS /* GOTO_DEFAULT, GOTO_LABELS, GOTO_OFFSET */
@@ -97,6 +105,7 @@ Shortcut shortcuts[] = {
   {GDK_SHIFT_MASK,     GDK_question,      sc_focus_inputbar,    NORMAL,              { .data = "?" } },
   {0,                  GDK_colon,         sc_focus_inputbar,    NORMAL,              { .data = ":" } },
   {0,                  GDK_o,             sc_focus_inputbar,    NORMAL,              { .data = ":open " } },
+  {0,                  GDK_O,             sc_focus_inputbar,    NORMAL,              { APPEND_FILEPATH, .data = ":open " } },
   {0,                  GDK_f,             sc_follow,            NORMAL,              {0} },
   {0,                  GDK_J,             sc_navigate,          NORMAL,              { NEXT } },
   {0,                  GDK_K,             sc_navigate,          NORMAL,              { PREVIOUS } },
@@ -131,12 +140,15 @@ Shortcut shortcuts[] = {
   {GDK_CONTROL_MASK,   GDK_f,             sc_scroll,            NORMAL,              { FULL_DOWN } },
   {GDK_CONTROL_MASK,   GDK_b,             sc_scroll,            NORMAL,              { FULL_UP } },
   {0,                  GDK_space,         sc_scroll,            NORMAL,              { FULL_DOWN } },
-  {0,                  GDK_O,             sc_switch_goto_mode,  NORMAL,              {0} },
+  {0,                  GDK_0,             sc_switch_goto_mode,  NORMAL,              {0} },
   {0,                  GDK_F5,            sc_toggle_fullscreen, NORMAL | FULLSCREEN, {0} },
   {0,                  GDK_Tab,           sc_toggle_index,      NORMAL | INDEX,      {0} },
   {GDK_CONTROL_MASK,   GDK_m,             sc_toggle_inputbar,   NORMAL,              {0} },
   {GDK_CONTROL_MASK,   GDK_n,             sc_toggle_statusbar,  NORMAL,              {0} },
   {GDK_CONTROL_MASK,   GDK_q,             sc_quit,              ALL,                 {0} },
+  {0,                  GDK_plus,          sc_zoom,              NORMAL | FULLSCREEN, { ZOOM_IN } },
+  {0,                  GDK_minus,         sc_zoom,              NORMAL | FULLSCREEN, { ZOOM_OUT } },
+  {0,                  GDK_equal,         sc_zoom,              NORMAL | FULLSCREEN, { ZOOM_ORIGINAL } },
 };
 
 /* inputbar shortcuts */
@@ -209,7 +221,7 @@ SpecialCommand special_commands[] = {
 /* settings */
 Setting settings[] = {
   /* name,                   variable,                           type,  render,  re-init, description */
-  {"adjust_open",            &(adjust_open),                     'i',   FALSE,   FALSE,   "Command to open URIs"},
+  {"adjust_open",            &(adjust_open),                     'i',   FALSE,   FALSE,   "Adjust mode"},
   {"browser",                &(uri_command),                     's',   FALSE,   FALSE,   "Command to open URIs"},
   {"completion_bgcolor",     &(completion_bgcolor),              's',   FALSE,   TRUE,    "Completion background color"},
   {"completion_fgcolor",     &(completion_fgcolor),              's',   FALSE,   TRUE,    "Completion foreground color"},
@@ -237,12 +249,13 @@ Setting settings[] = {
   {"recolor_darkcolor",      &(recolor_darkcolor),               's',   FALSE,   TRUE,    "Recoloring (dark color)"},
   {"recolor_lightcolor",     &(recolor_lightcolor),              's',   FALSE,   TRUE,    "Recoloring (light color)"},
   {"scroll_step",            &(scroll_step),                     'f',   FALSE,   FALSE,   "Scroll step"},
+  {"scroll_wrap",            &(scroll_wrap),                     'b',   FALSE,   FALSE,   "Wrap scolling at last page"},
   {"scrollbars",             &(show_scrollbars),                 'b',   FALSE,   TRUE,    "Show scrollbars"},
   {"show_statusbar",         &(Zathura.Global.show_statusbar),   'b',   FALSE,   TRUE,    "Show statusbar"},
   {"show_inputbar",          &(Zathura.Global.show_inputbar),    'b',   FALSE,   TRUE,    "Show inputbar"},
   {"search_highlight",       &(search_highlight),                's',   FALSE,   TRUE,    "Highlighted results"},
   {"select_text",            &(select_text),                     's',   FALSE,   TRUE,    "Rectangle of the selected text"},
-  {"smooth_scrolling",       &(smooth_scrolling),                'f',   FALSE,   TRUE,    "Show scrollbars"},
+  {"smooth_scrolling",       &(smooth_scrolling),                'f',   FALSE,   TRUE,    "Smooth scrolling"},
   {"statusbar_bgcolor",      &(statusbar_bgcolor),               's',   FALSE,   TRUE,    "Statusbar background color"},
   {"statusbar_fgcolor",      &(statusbar_fgcolor),               's',   FALSE,   TRUE,    "Statusbar foreground color"},
   {"transparency",           &(transparency),                    'f',   FALSE,   FALSE,   "Transparency of rectangles"},
